@@ -7,6 +7,7 @@
 # Contact email: tomkralidis@gmail.com
 # =============================================================================
 
+from io import BytesIO
 from urllib.parse import urlencode
 from owslib.util import (
     testXMLValue,
@@ -33,7 +34,6 @@ from owslib.feature import WebFeatureService_
 from owslib.feature.common import (
     WFSCapabilitiesReader,
     AbstractContentMetadata,
-    makeStringIO,
 )
 from owslib.namespaces import Namespaces
 from owslib.util import log, openURL
@@ -132,7 +132,7 @@ class WebFeatureService_1_1_0(WebFeatureService_):
         if xml:
             self._capabilities = reader.readString(xml)
         else:
-            self._capabilities = reader.read(self.url)
+            self._capabilities = reader.read(self.url, self.timeout)
         self._buildMetadata(parse_remote_metadata)
 
     def _buildMetadata(self, parse_remote_metadata=False):
@@ -186,9 +186,10 @@ class WebFeatureService_1_1_0(WebFeatureService_):
         features = self._capabilities.findall(
             nspath_eval("wfs:FeatureTypeList/wfs:FeatureType", namespaces)
         )
-        for feature in features:
-            cm = ContentMetadata(feature, parse_remote_metadata, headers=self.headers, auth=self.auth)
-            self.contents[cm.id] = cm
+        if features is not None:
+            for feature in features:
+                cm = ContentMetadata(feature, parse_remote_metadata, headers=self.headers, auth=self.auth)
+                self.contents[cm.id] = cm
 
         # exceptions
         self.exceptions = [
@@ -219,7 +220,7 @@ class WebFeatureService_1_1_0(WebFeatureService_):
         bbox=None,
         featureid=None,
         featureversion=None,
-        propertyname="*",
+        propertyname=None,
         maxfeatures=None,
         srsname=None,
         outputFormat=None,
@@ -242,7 +243,8 @@ class WebFeatureService_1_1_0(WebFeatureService_):
         featureversion : string
             Default is most recent feature version.
         propertyname : list
-            List of feature property names. '*' matches all.
+            List of feature property names. For Get request, '*' matches all.
+            For Post request, leave blank (None) to get all properties.
         maxfeatures : int
             Maximum number of features to be returned.
         method : string
@@ -277,53 +279,72 @@ class WebFeatureService_1_1_0(WebFeatureService_):
             base_url = self.url
         request = {"service": "WFS", "version": self.version, "request": "GetFeature"}
 
-        if not isinstance(typename, list):
-            typename = [typename]
+        if method.lower() == "get":
+            if not isinstance(typename, list):
+                typename = [typename]
 
-        if srsname is not None:
-            request["srsname"] = str(srsname)
+            if srsname is not None:
+                request["srsname"] = str(srsname)
 
-            # Check, if desired SRS is supported by the service for each
-            # typename. Warning will be thrown if that SRS is not allowed."
-            for name in typename:
-                _ = self.getSRS(srsname, name)
+                # Check, if desired SRS is supported by the service for each
+                # typename. Warning will be thrown if that SRS is not allowed."
+                for name in typename:
+                    _ = self.getSRS(srsname, name)
 
-        # check featureid
-        if featureid:
-            request["featureid"] = ",".join(featureid)
+            # check featureid
+            if featureid:
+                request["featureid"] = ",".join(featureid)
 
-        # bbox
-        elif bbox and typename:
-            request["bbox"] = self.getBBOXKVP(bbox, typename)
+            # bbox
+            elif bbox and typename:
+                request["bbox"] = self.getBBOXKVP(bbox, typename)
 
-        # or filter
-        elif filter and typename:
-            request["filter"] = str(filter)
+            # or filter
+            elif filter and typename:
+                request["filter"] = str(filter)
 
-        assert len(typename) > 0
-        request["typename"] = ",".join(typename)
+            assert len(typename) > 0
+            request["typename"] = ",".join(typename)
+
+            if propertyname is None:
+                propertyname = "*"
 
-        if propertyname is not None:
             if not isinstance(propertyname, list):
                 propertyname = [propertyname]
             request["propertyname"] = ",".join(propertyname)
 
-        if sortby is not None:
-            if not isinstance(sortby, list):
-                sortby = [sortby]
-            request["sortby"] = ",".join(sortby)
+            if sortby is not None:
+                if not isinstance(sortby, list):
+                    sortby = [sortby]
+                request["sortby"] = ",".join(sortby)
 
-        if featureversion is not None:
-            request["featureversion"] = str(featureversion)
-        if maxfeatures is not None:
-            request["maxfeatures"] = str(maxfeatures)
-        if startindex is not None:
-            request["startindex"] = str(startindex)
-        if outputFormat is not None:
-            request["outputFormat"] = outputFormat
+            if featureversion is not None:
+                request["featureversion"] = str(featureversion)
+            if maxfeatures is not None:
+                request["maxfeatures"] = str(maxfeatures)
+            if startindex is not None:
+                request["startindex"] = str(startindex)
+            if outputFormat is not None:
+                request["outputFormat"] = outputFormat
+
+            data = urlencode(request)
+            log.debug("Making request: %s?%s" % (base_url, data))
+
+        elif method.lower() == "post":
+            base_url, data = self.getPOSTGetFeatureRequest(
+                typename=typename,
+                filter=filter,
+                bbox=bbox,
+                featureid=featureid,
+                featureversion=featureversion,
+                propertyname=propertyname,
+                maxfeatures=maxfeatures,
+                outputFormat=outputFormat,
+                method='Post',
+                startindex=startindex,
+                sortby=sortby,
+            )
 
-        data = urlencode(request)
-        log.debug("Making request: %s?%s" % (base_url, data))
         u = openURL(base_url, data, method, timeout=self.timeout,
                     headers=self.headers, auth=self.auth)
 
@@ -346,16 +367,16 @@ class WebFeatureService_1_1_0(WebFeatureService_):
                 tree = etree.fromstring(data)
             except BaseException:
                 # Not XML
-                return makeStringIO(data)
+                return BytesIO(data)
             else:
                 if tree.tag == "{%s}ServiceExceptionReport" % namespaces["ogc"]:
                     se = tree.find(nspath_eval("ServiceException", namespaces["ogc"]))
                     raise ServiceException(str(se.text).strip())
                 else:
-                    return makeStringIO(data)
+                    return BytesIO(data)
         else:
             if have_read:
-                return makeStringIO(data)
+                return BytesIO(data)
             return u
 
     def getOperationByName(self, name):
