@@ -8,18 +8,18 @@
 
 import logging
 
-from owslib.ogcapi import API
+from owslib.ogcapi import Collections
 from owslib.util import Authentication
 
 LOGGER = logging.getLogger(__name__)
 
 
-class Features(API):
+class Features(Collections):
     """Abstraction for OGC API - Features"""
 
     def __init__(self, url: str, json_: str = None, timeout: int = 30,
                  headers: dict = None, auth: Authentication = None):
-        __doc__ = API.__doc__  # noqa
+        __doc__ = Collections.__doc__  # noqa
         super().__init__(url, json_, timeout, headers, auth)
 
     def feature_collections(self) -> dict:
@@ -59,7 +59,7 @@ class Features(API):
         """
 
         if 'bbox' in kwargs:
-            kwargs['bbox'] = ','.join(kwargs['bbox'])
+            kwargs['bbox'] = ','.join(list(map(str, kwargs['bbox'])))
 
         path = 'collections/{}/items'.format(collection_id)
         return self._request(path=path, kwargs=kwargs)
