@@ -407,7 +407,7 @@ def http_post(url=None, request=None, lang='en-US', timeout=10, username=None, p
     headers = {
         'User-Agent': 'OWSLib (https://geopython.github.io/OWSLib)',
         'Content-type': 'text/xml',
-        'Accept': 'text/xml',
+        'Accept': 'text/xml,application/xml',
         'Accept-Language': lang,
         'Accept-Encoding': 'gzip,deflate',
         'Host': u.netloc,
@@ -872,6 +872,14 @@ class Authentication(object):
             username/password arguments.
         '''
         self.shared = shared
+        self._username = username
+        self._password = password
+        self._cert = cert
+        self._verify = verify
+        self._auth_delegate = auth_delegate
+
+        # Trigger the setters to validate the parameters. This couldn't be done directly
+        # since some parameters are mutually exclusive.
         self.username = username
         self.password = password
         self.cert = cert
